====================
:program:`satori`
====================

OpenStack Configuration Discovery

SYNOPSIS
========

:program:`satori`


DESCRIPTION
===========

:program:`satori` provides configuration discovery.



OPTIONS
=======

:program:`satori` has no options yet


AUTHORS
=======

Please refer to the AUTHORS file distributed with Satori.


COPYRIGHT
=========

Copyright 2011-2013 OpenStack Foundation and the authors listed in the AUTHORS file.


LICENSE
=======

http://www.apache.org/licenses/LICENSE-2.0


SEE ALSO
========

The `Satori page <https://wiki.openstack.org/wiki/Satori>`_
in the `OpenStack Wiki <https://wiki.openstack.org/>`_ contains further
documentation.
s
The individual OpenStack project CLIs, the OpenStack API references.